/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2014 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.annotation.view;

import org.eclipse.jface.viewers.ColumnLabelProvider;
import org.eclipse.swt.graphics.Color;
import org.eclipse.wb.swt.SWTResourceManager;
import org.fortiss.tooling.base.model.element.IModelElement;
import org.fortiss.tooling.base.ui.annotation.AnnotationEntry;
import org.fortiss.tooling.kernel.model.INamedElement;

/**
 * Provider that uses the names of {@link INamedElement}s as column labels.
 * 
 * @author barner
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating RED Hash:
 */
public class ElementNameLabelProvider extends ColumnLabelProvider {
	/** The view part in which this {@link ElementNameLabelProvider} is used. */
	private final IAnnotationViewPart viewPart;

	/** Creates a new {@link ElementNameLabelProvider} for a given {@code column}. */
	public ElementNameLabelProvider(IAnnotationViewPart viewPart) {
		this.viewPart = viewPart;
	}

	/** {@inheritDoc} */
	@Override
	public String getText(Object element) {
		if(!(element instanceof AnnotationEntry)) {
			return "-";
		}

		IModelElement modelElement = ((AnnotationEntry)element).getModelElement();

		if(modelElement instanceof INamedElement) {
			return ((INamedElement)modelElement).getName();
		}
		return "-";
	}

	/** {@inheritDoc} */
	@Override
	public Color getBackground(Object element) {
		if(element instanceof AnnotationEntry) {
			AnnotationEntry data = (AnnotationEntry)element;
			if(data.getModelElement().equals(viewPart.getCurrentlySelectedObject())) {
				return SWTResourceManager.getColor(0, 255, 0);
			}
		}
		return super.getBackground(element);
	}
}
