/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 ForTISS GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.ui.service;

import org.eclipse.jface.action.IMenuManager;
import org.eclipse.ui.IActionBars;
import org.fortiss.tooling.kernel.ui.internal.ActionService;

/**
 * The action service manages registration and execution of actions including
 * global actions like undo, redo, and delete.
 * 
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating GREEN Hash: B12A8EF1D028E82503F0BF59DBAF9398
 */
public interface IActionService {

	/** Returns the singleton instance of the service. */
	public static final IActionService INSTANCE = new ActionService();

	/** Registers all global actions with the given {@link IActionBars}. */
	void registerGlobalActions(IActionBars actionBars);

	/**
	 * Registers the global unde/redo action with the given {@link IActionBars}.
	 */
	public void registerGlobalUndoRedoActions(IActionBars actionBars);

	/** Registers the global editing action with the given {@link IActionBars}. */
	public void registerGlobalEditingActions(IActionBars actionBars);

	/**
	 * Adds the global default actions to the given context menu. Currently the
	 * default are the editing actions as provided by #
	 * {@link IActionService#addGlobalEditingActionsToMenu(IMenuManager)}.
	 */
	void addGlobalDefaultActionSectionToMenu(IMenuManager menuManager);

	/** Adds the global editing actions to the menu (Copy, Cut, Paste, Delete). */
	void addGlobalEditingActionsToMenu(IMenuManager menuManager);

	/** Adds the global undo/redo actions to the menu. */
	void addGlobalUndoRedoActionsToMenu(IMenuManager menuManager);

	/**
	 * Refreshes the enabled state of the global actions. This method should be
	 * called when a selection changes. It is automatically called by the action
	 * service when any command stack changes.
	 */
	void refresh();
}
