/*-------------------------------------------------------------------------+
|                                                                          |
| Copyright 2005-2011 The ConQAT Project                                   |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+-------------------------------------------------------------------------*/
package org.conqat.ide.commons.ui.pref;

import java.util.regex.Pattern;

import org.conqat.lib.commons.string.StringUtils;
import org.eclipse.jface.dialogs.InputDialog;
import org.eclipse.jface.preference.ListEditor;
import org.eclipse.jface.window.Window;
import org.eclipse.swt.widgets.Composite;

/**
 * A field editor for dealing with lists of patterns.
 * 
 * @author $Author: hummelb $
 * @version $Rev: 32168 $
 * @ConQAT.Rating GREEN Hash: 1F7C8E3D5381995FA952E9B91195B3C8
 */
public abstract class PatternListEditorBase extends ListEditor {

	/**
	 * The String used to separate the regular expressions. As this is not a
	 * valid String in a regular expression, we can safely use it.
	 */
	private static final String SEPARATOR = "**#**";

	/** A quoted version of {@link #SEPARATOR}. */
	private static final String QUOTED_SEPARATOR = Pattern.quote(SEPARATOR);

	/** Constructor. */
	protected PatternListEditorBase(String name, String labelText, Composite parent) {
		super(name, labelText, parent);
	}

	/** {@inheritDoc} */
	@Override
	protected String createList(String[] items) {
		return concat(items);
	}

	/** Concatenate the given items using the internal separator. */
	public static String concat(String[] items) {
		return StringUtils.concat(items, SEPARATOR);
	}

	/** {@inheritDoc} */
	@Override
	protected String getNewInputObject() {
		InputDialog inputDialog = createInputDialog ();
		if (inputDialog.open() == Window.OK) {
			return inputDialog.getValue();
		}
		return null;
	}

	/** Template method for opening a text input box used to enter a new pattern.*/
	protected abstract InputDialog createInputDialog();

	/** {@inheritDoc} */
	@Override
	protected String[] parseString(String stringList) {
		return split(stringList);
	}

	/** Split the given string using the internal separator. */
	public static String[] split(String stringList) {
		if (StringUtils.isEmpty(stringList)) {
			return new String[0];
		}
		return stringList.split(QUOTED_SEPARATOR);
	}
}