/*-------------------------------------------------------------------------+
|                                                                          |
| Copyright 2005-2011 The ConQAT Project                                   |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+-------------------------------------------------------------------------*/
package org.conqat.ide.commons.ui.validators;

import org.eclipse.core.databinding.validation.IValidator;
import org.eclipse.core.databinding.validation.ValidationStatus;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.jface.dialogs.IInputValidator;
import org.eclipse.jface.viewers.ICellEditorValidator;

/**
 * Utility class for {@link IValidator}s, {@link ICellEditorValidator}s and
 * {@link IInputValidator}s.
 * 
 * @author streitel
 * @author $Author: deissenb $
 * @version $Rev: 34252 $
 * @levd.rating GREEN Hash: EA392F1B0EBA1B4592A1B67FC0D6006C
 */
public class ValidatorUtils {

	/**
	 * Returns an {@link ICellEditorValidator} that encapsulates an
	 * {@link IValidator}.
	 */
	public static ICellEditorValidator modelValidatorToCellEditorValidator(
			final IValidator modelValidator) {
		return new ICellEditorValidator() {

			@Override
			public String isValid(Object input) {
				IStatus status = modelValidator.validate(input);
				if (status.getSeverity() == IStatus.ERROR) {
					return status.getMessage();
				}
				return null;
			}
		};
	}

	/**
	 * Returns an {@link IValidator} that encapsulates an
	 * {@link IInputValidator}.
	 */
	public static IValidator inputValidatorToModelValidator(
			final IInputValidator inputValidator) {
		return new IValidator() {

			@Override
			public IStatus validate(Object value) {
				String message = inputValidator.isValid((String) value);
				if (message == null) {
					return ValidationStatus.ok();
				}
				return ValidationStatus.error(message);
			}
		};
	}

}