/*-------------------------------------------------------------------------+
|                                                                          |
| Copyright 2005-2011 The ConQAT Project                                   |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+-------------------------------------------------------------------------*/
package org.conqat.ide.commons.ui.xmlmodel.databinding;

import org.eclipse.core.databinding.observable.Realm;
import org.eclipse.core.databinding.observable.value.IObservableValue;

import org.conqat.ide.commons.ui.xmlmodel.ElementBase;
import org.conqat.ide.commons.ui.xmlmodel.XmlRootModelBase;

/**
 * Creates observables for the CQ XML models.
 * 
 * @author hummelb
 * @author $Author: deissenb $
 * @version $Rev: 34252 $
 * @levd.rating GREEN Hash: F82A366B7EE2AFCE389CE0889FDEDCDB
 */
public class XmlModelObservables {

	/** Returns an observable for the given object and beans property. */
	public static IObservableValue observeValue(ElementBase<?> element,
			String propertyName) {
		return observeValue(Realm.getDefault(), element, propertyName);
	}

	/** Returns an observable for the given model and beans property. */
	public static IObservableValue observeValue(XmlRootModelBase model,
			String propertyName) {
		return observeValue(Realm.getDefault(), model, propertyName);
	}

	/** Returns an observable for the given object and beans property. */
	public static IObservableValue observeValue(Realm realm,
			ElementBase<?> element, String propertyName) {
		// error handling policy here is to re-throw as unchecked exception, as
		// all of these indicate programming errors.
		try {
			return new XmlModelObservableValue(realm, element, element
					.getModel(), propertyName);
		} catch (SecurityException e) {
			throw new AssertionError(e);
		} catch (NoSuchMethodException e) {
			throw new AssertionError(e);
		}
	}

	/** Returns an observable for the given model and beans property. */
	public static IObservableValue observeValue(Realm realm,
			XmlRootModelBase model, String propertyName) {
		// error handling policy here is to re-throw as unchecked exception, as
		// all of these indicate programming errors.

		try {
			return new XmlModelObservableValue(realm, model, model,
					propertyName);
		} catch (SecurityException e) {
			throw new AssertionError(e);
		} catch (NoSuchMethodException e) {
			throw new AssertionError(e);
		}
	}

}